@@ -1,10 +1,10 @@
-__version__ = "0.3.21"
+__version__ = "0.3.22"
 __git_commiter_name__ = "Guy Rozendorn"
 __git_commiter_email__ = "guy@rzn.co.il"
-__git_branch__ = '(detached from v0.3.21)'
+__git_branch__ = '(detached from v0.3.22)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'cce4cff8efb5b5406e6f16b2fa9e246e70f14eb0'
-__git_head_subject__ = 'STORAGEMODEL-255 EUI64_16Byte_Designator.identifier_extension is 8 bytes'
+__git_head_hash__ = '861795d1d3cdd39275979d72b46e579597288a29'
+__git_head_subject__ = 'win32: fixing handle'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
